From 6a665196eca9ce00ef37456162cccfab03fe9f37 Mon Sep 17 00:00:00 2001
From: Rytis Sileika <rytis.sileika@gmail.com>
Date: Wed, 9 Dec 2009 15:50:36 +0000
Subject: [PATCH] Introducing new setting 'rsync_user', which (if defined) will be appended to rsync command when pulling config from remote master server

---
 CHANGELOG                             |    3 +++
 cobbler/action_replicate.py           |    5 ++++-
 installer_templates/settings.template |    5 ++++-
 3 files changed, 11 insertions(+), 2 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index 37f5457..4e8d0ad 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,5 +1,8 @@
 Cobbler CHANGELOG
 
+- Dec 08 2009 - 2.0.3
+- (FEAT) Added settings item to specify rsync user account for replication
+
 - Nov 23 2009 - 2.0.2
 - (FEAT) Added support for Cobbler4j
 - (FEAT) Added method for enabling autostart on qemu domains
diff --git a/cobbler/action_replicate.py b/cobbler/action_replicate.py
index 1b75755..3a8865f 100644
--- a/cobbler/action_replicate.py
+++ b/cobbler/action_replicate.py
@@ -49,8 +49,11 @@ class Replicate:
         self.logger   = logger
 
     def rsync_it(self,from_path,to_path):
+        rsync_user = ''
+        if hasattr(self.settings, 'rsync_user'):
+            rsync_user = "%s@" % self.settings.rsync_user
         from_path = "%s::%s" % (self.host, from_path)
-        cmd = "rsync -avz %s %s" % (from_path, to_path)
+        cmd = "rsync -avz %s%s %s" % (rsync_user, from_path, to_path)
         rc = utils.subprocess_call(self.logger, cmd, shell=True)
         if rc !=0:
             self.logger.info("rsync failed")
diff --git a/installer_templates/settings.template b/installer_templates/settings.template
index 2777b73..045df38 100644
--- a/installer_templates/settings.template
+++ b/installer_templates/settings.template
@@ -344,4 +344,7 @@ yum_distro_priority: 1
 # --resolve.
 yumdownloader_flags: "--resolve"
 
-
+# Cobbler replicate uses rsync (over ssh) to pull some data from the remote server
+# This setting allows you to specify which remote user account to use
+# Comment out and it will use same user account that was used to run 'cobbler' command
+rsync_user: rsync
-- 
1.5.2.5

